/*
 * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */

/**
 * Defines tools for transforming a JAR file into a compressed pack200 file
 * and transforming a packed file into a JAR file, including the
 * <em>{@index pack200 pack200 tool}</em> and
 * <em>{@index unpack200 unpack200 tool}</em> tools.
 *
 * @toolGuide pack200
 * @toolGuide unpack200
 *
 * @moduleGraph
 * @deprecated This module is deprecated, and is planned for removal in a
 *             future release.
 * @since 9
 */
@Deprecated(since="11", forRemoval=true)
module jdk.pack {
}
